@@ -126,11 +126,15 @@ fn generate_provider_item(
         use_statements,
     };
     let compiled = usdt_impl::compile_provider(&provider, &config);
-    let type_checks = quote! {
-        const _: fn() = || {
-            fn usdt_types_must_be_serializable<T: ?Sized + ::serde::Serialize>() {}
-            #(#check_fns)*
-        };
+    let type_checks = if check_fns.is_empty() {
+        quote! { const _: fn() = || {}; }
+    } else {
+        quote! {
+            const _: fn() = || {
+                fn usdt_types_must_be_clone_and_serialize<T: ?Sized + Clone + ::serde::Serialize>() {}
+                #(#check_fns)*
+            };
+        }
     };
     let mut content = mod_.content.as_ref().unwrap().1.clone();
     content.push(syn::parse2(type_checks).unwrap());
@@ -162,6 +166,8 @@ fn parse_probe_argument(
                 .ident;
             if is_simple_type(last_ident) {
                 Ok((None, data_type_from_path(&path.path)))
+            } else if last_ident == "UniqueId" {
+                Ok((None, DataType::UniqueId))
             } else {
                 let check_fn = build_serializable_check_function(item, fn_index, arg_index);
                 Ok((Some(check_fn), DataType::Serializable(item.clone())))
@@ -169,7 +175,8 @@ fn parse_probe_argument(
         }
         syn::Type::Reference(ref reference) => {
             match parse_probe_argument(&*reference.elem, fn_index, arg_index)? {
-                (None, ty) => Ok((None, ty)),
+                (None, DataType::UniqueId) => Ok((None, DataType::UniqueId)),
+                (None, DataType::Native(ty)) => Ok((None, DataType::Native(ty))),
                 _ => Ok((
                     Some(build_serializable_check_function(item, fn_index, arg_index)),
                     DataType::Serializable(item.clone()),
@@ -211,13 +218,16 @@ fn build_serializable_check_function<T>(ident: &T, fn_index: usize, arg_index: u
 where
     T: quote::ToTokens,
 {
-    let fn_name =
-        quote::format_ident!("usdt_types_must_be_serializable_{}_{}", fn_index, arg_index);
+    let fn_name = quote::format_ident!(
+        "usdt_types_must_be_clone_and_serialize_{}_{}",
+        fn_index,
+        arg_index
+    );
     quote! {
         fn #fn_name() {
             // #ident must be in scope here, because this function is defined in the same module as
             // the actual probe functions, and thus shares any imports the consumer wants.
-            usdt_types_must_be_serializable::<#ident>()
+            usdt_types_must_be_clone_and_serialize::<#ident>()
         }
     }
 }
@@ -301,11 +311,15 @@ mod tests {
     fn test_data_type_from_path() {
         assert_eq!(
             data_type_from_path(&syn::parse_str("u8").unwrap()),
-            DataType::Native(dtrace_parser::DataType::U8)
+            DataType::Native(dtrace_parser::DataType::U8),
         );
         assert_eq!(
             data_type_from_path(&syn::parse_str("String").unwrap()),
-            DataType::Native(dtrace_parser::DataType::String)
+            DataType::Native(dtrace_parser::DataType::String),
+        );
+        assert_eq!(
+            data_type_from_path(&syn::parse_str("String").unwrap()),
+            DataType::Native(dtrace_parser::DataType::String),
         );
     }
 
@@ -320,7 +334,7 @@ mod tests {
     #[case("&u8", dtrace_parser::DataType::U8)]
     #[case("&str", dtrace_parser::DataType::String)]
     #[case("String", dtrace_parser::DataType::String)]
-    #[case("&str", dtrace_parser::DataType::String)]
+    #[case("&&str", dtrace_parser::DataType::String)]
     #[case("&String", dtrace_parser::DataType::String)]
     fn test_parse_probe_argument_native(#[case] name: &str, #[case] ty: dtrace_parser::DataType) {
         let arg = syn::parse_str(name).unwrap();
@@ -329,6 +343,16 @@ mod tests {
         assert_eq!(out.1, DataType::Native(ty));
     }
 
+    #[rstest]
+    #[case("usdt::UniqueId")]
+    #[case("&usdt::UniqueId")]
+    fn test_parse_probe_argument_span(#[case] arg: &str) {
+        let ty = syn::parse_str(arg).unwrap();
+        let out = parse_probe_argument(&ty, 0, 0).unwrap();
+        assert!(out.0.is_none());
+        assert_eq!(out.1, DataType::UniqueId)
+    }
+
     #[rstest]
     #[case("std::net::IpAddr")]
     #[case("&std::net::IpAddr")]
